@@ -73,12 +73,13 @@ module.exports=function(db,config,validator,jvm,manifest){
     }*/
 
     app.use(function(req,res,next){
-        logger.info("client req "+req.url);
+         logger.info("client req "+req.url);
 
          req._r=db;
          req._config=config;
          req._validator=validator;
          req._jvm=jvm;
+         req._logger=logger;
          next();
 
     });
@@ -97,11 +98,31 @@ module.exports=function(db,config,validator,jvm,manifest){
     //config static
     app.use(express.static(work_dir+'/public'));
 
-    //app.use(function(req, res) {
-     // var url = req.url;
+    app.use(function(req, res,next) {
+      var url = req.url;
+      if(url.indexOf('api')>=0){
+         // res.sendFile(work_dir+'/public/index.html',404);
+          //resst.send('Page Not Found',404);
+         // var err = new Error('Not Found');
+         // err.status = 404;
+         // next(err);
+
+          res.status(404);
+          res.send('Page Not Found');
+     
+      } else if(url.indexOf('.')>=0){
+         // var err = new Error('Not Found');
+         // err.status = 404;
+         // next(err);
+          res.status(404);
+          res.send('Page Not Found');
+      }
+      else{
+          res.sendFile(work_dir+'/public/index.html',404);
+      }
+      
       
-    //  res.sendFile(work_dir+'/public/index.html',404);
      // next();
-  //  });
+   });
     return app;
 }
