@@ -1,6 +1,8 @@
 var fs=require('fs');
 var java = require('java');
 var jvm=java;
+var logger = require('winston');
+
 var loadJava=function(path){
     fs.readdir(path, function(err, files) { 
          files.forEach(function(filename) {
@@ -10,7 +12,7 @@ var loadJava=function(path){
                             loadJava(path+"/"+filename);
                         }else{
                             if(filename.endsWith(".jar")){
-                                 console.log("Load Java .jar :: "+ filename);
+                                 logger.info("Load Java .jar :: "+ filename);
                                  jvm.classpath.push(path+"/"+filename);
                             }
                         }
